% ------------------------------------------------------------------------
% BMCAPMTEST: 
% Tests of CAPM
% 
%  Xiaoji Lin and Lu Zhang, Inc. 2012.
%--------------------------------------------------------------------------

clear all; close all; clc

%Here you pre-define the sample that you want to use
year0=1930; quarter0=year0*10+1; month0=year0*100+1; %Should start in first quarter/month.
year1=2010; quarter1=year1*10+4; month1=year1*100+12; %Should end in last quarter/month.

% 1. A description of data sets: missing value is set to zero
%--------------------------------------------------------------------------
%  annual data
% Data1: FF3 monthly factors 
% Data2: 10 BM monthly returns

Data1 = load('F-F_Research_Data_Factors_Monthly.txt');     ini1=find(Data1(:,1)==month0); fin1=find(Data1(:,1)==month1); 
Data2 = load('Portfolios_Formed_on_BE-ME_Monthly.txt');    ini2=find(Data2(:,1)==month0); fin2=find(Data2(:,1)==month1); 

%------------------------------------------------------------------------
% 2.Test of CAPM
%  calculate mean and std deviation
MktPrem = Data1(ini1:fin1,2);
RF      = Data1(ini1:fin1,end);
BM      = Data2(ini2:fin2,11:end);

RF_m    = mean(RF);
BMRF    = [BM - RF*ones(1,10) BM(:,end)-BM(:,1)];  % excess returns;

BM_m    = mean(BMRF) ;
MktPrem_m = mean(MktPrem);

% std
BM_std      = std(BMRF);
MktPrem_std = std(MktPrem);
RF_std      = std(RF);

%--------------------------------------------------------------------------
% Unconditional CAPM
[T N] = size(BMRF);
bv = []; sebv =[];
X = ones(T,1);
rhv = [X MktPrem];
lhv = BMRF; 

for i = 1 : N;
        lags = 24; 
        weight = 1; 
        [bv(:,i),sebv(:,i),R2v(:,i),R2vadj(i),v,F] = olsgmm(lhv(:,i),rhv,lags,weight);
end; 
    
alpha_BM = bv(1,:);
beta_BM  = bv(2,:);
t_alpha_BM = bv(1,:)./sebv(1,:);
t_beta_BM = bv(2,:)./sebv(2,:);

% print results in Latex
head = {'Growth';'2';'3';'4';'5';'6';'7';'8';'9';'Value';'V-G'};
fmt = ' %G6.2 ';
row = { 'mean';'std';'alpha'; 't(alpha)'; 'beta';'t(beta)';'AdjR2'};
Forecasts=[BM_m;BM_std;alpha_BM;t_alpha_BM;beta_BM;t_beta_BM;R2vadj;];
texprint(Forecasts, '%6.2f', head, row);






