function [bv] = FF3SLP(rfs, mktRet, FF6_VW, Ret )

% FF3SLP: calculate FF3 factors and do time series regressions
% 
% INPUT:
%   rfs: T periods of risk free rate
%   mktRet: T periods of market return
%   FF6_VW: 2 by 3 by T periods of size/bm portfolios
%   Ret: N by T firm returns

% OUTPUT:
%   bv: coefficents 

%  Xiaoji lin and Lu Zhang 2012

% warning off

% construct SMB and HML
SMB = (  FF6_VW(1,1,:,:) + FF6_VW(1,2,:,:) + FF6_VW(1,3,:,:) ...
         - FF6_VW(2,1,:,:) - FF6_VW(2,2,:,:) - FF6_VW(2,3,:,:) )/3;
HML = ( FF6_VW(1,3,:,:) + FF6_VW(2,3,:,:) - FF6_VW(1,1,:,:) - FF6_VW(2,1,:,:) )/2;

Ret_excess = mktRet - rfs;
[N T]      = size(Ret);
T          = floor(T/12)*12-0;
Ret_excess = Ret_excess(1:T);
rfs        = rfs(1:T);
Ret        = Ret(:,1:T);

% adjust the dimension of SMB and HML
SMB = squeeze(SMB);
HML = squeeze(HML);

bv=[];X = ones(T,1);
lhv  =[];

RRet = Ret';
RF   = repmat(rfs,[1 N]);
lhv = RRet -RF; 
rhv = [X  Ret_excess SMB HML];
bv = rhv\lhv;
bv = bv';



