
function lambda = getLambda(x, beta, gamA, gamB, xbar, rhox, stdx)

% GETLAMBDA:
%   price of risk (lambda) as a function of aggregate shock given other parameter values where pricing kernel:
% 
%                 log(M_{t,t+1}) = log(beta) + (gamA + gamB*(x_t - xbar))*(x_t - x_{t+1})
% 
%   em   - E_t[M_{t+1}]
%   sigm - \sigma_t[M_{t+1}]
%   Sp   - sigm/em
%   lambda - sigm^2/em
% 
%  Xiaoji lin and Lu Zhang 2012

mu  = (gamA + gamB*(x - xbar))*(1 - rhox).*(x - xbar);
sig = stdx*(gamA + gamB*(x - xbar));

em   = beta*exp(mu + (1/2)*sig.^2);
sigm = beta*exp(mu).*sqrt( exp(sig.^2) .* (exp(sig.^2) - 1) );
Sp   = sigm./em;
lambda = sigm.^2./em;

