
function [phy10] = portSort10VW(phy, P, Ret)

% PORTSORT10VW: Sort 10 value-weighted physical investment portfolios
% 
% INPUT:
%   phy: N by T matrix of sorting variable
%   P:   N by T matrix of firm market capitalization
%   Ret: N by T matrix of individual firm returns

% OUTPUT:
%   phy10: 
% 
%  Xiaoji lin and Lu Zhang 2012

% warning off

% Initializing
[N, T]  = size(Ret);
pointer = round([1; N*.10; N*.20; N*.30; N*.40;N*.50; N*.60; N*.70; N*.80; N*.90; N]);  % pointers used in sorting

[N T]  = size(Ret);
T      = floor(T/12)*12;
P      = P(:,1:T);        
phy    = phy(:,1:T);     
Ret    = Ret(:,1:T);

% further initializing
lag   = 0;
phy10   = zeros([10 T - lag]);    % 10 portfolio returns formed on phy

% construct 25 portfolio returns
for t = lag + 1 : T
    % sorting and rebalancing once every year
    if (mod(t - 1, 12) == 0)       % using monthly returns
        % pick up rnd recorded at the beginning of a month
         phyvec  = phy(:, t);
         IndStru = phy10Sorting(phyvec, pointer);
        % construct equal-weighted phy10 portfolio excess returns 
         tSpan            = t : t + 11;         % using monthly returns
         [phy10(:, tSpan - lag)] = p10Constr(IndStru, tSpan, P, Ret);
        
     end 
end


%------------------------------subfunction declaration-----------------------------
% 
function IndStru = phy10Sorting(svec, pointer);

% phy10SORTING:
%
% sort 10 portfolios based on physical investment
% OUTPUT:
%   IndStru : structural cell (matrix of matrices of difference lengths)
% 
%  Xiaoji lin and Lu Zhang 2012

% Initializing
IndStru  = struct('idp1', [], 'idp2', [], 'idp3', [], 'idp4', [], 'idp5',[],'idp6', [], 'idp7', [], 'idp8', [], 'idp9', [], 'idp10',[]);
% phyiscal investment sort
[ssize, sInd] = sort(svec);     clear ssize
ids1    = sInd(pointer(1)     : pointer(2));
ids2    = sInd(pointer(2) + 1 : pointer(3));
ids3    = sInd(pointer(3) + 1 : pointer(4));
ids4    = sInd(pointer(4) + 1 : pointer(5));
ids5    = sInd(pointer(5) + 1 : pointer(6));     
ids6    = sInd(pointer(6) + 1 : pointer(7));
ids7    = sInd(pointer(7) + 1 : pointer(8));
ids8    = sInd(pointer(8) + 1 : pointer(9));
ids9    = sInd(pointer(9) + 1 : pointer(10));
ids10    = sInd(pointer(10) + 1 : pointer(11));     clear sInd

% take index to form 10 portfolios
for i = 1 : 10
    eval(['IndStru.idp' num2str(i) '=ids' num2str(i) ';' ]);
end

%---------------------------------------------------------------------------
% 
function [p10]   = p10Constr(IndStru, tSpan, P, Ret);

% p10Constr:
%   construct 10 portfolios using structural cell index across the time range in tSpan
%
% OUTPUT:
%   p10 : 10 by length(tSpan) portfolio returns
% 
%  Xiaoji lin and Lu Zhang 2012

[N, T]  = size(Ret);
p10 = zeros([10 length(tSpan)]);

for i = 1 : 10
   
        % value-weighted returns
         eval(['p10(' num2str(i) ', :) = sum(P(IndStru.idp' num2str(i) ', tSpan).*Ret(IndStru.idp' num2str(i) ', tSpan)) ./sum(P(IndStru.idp' ...
            num2str(i) ', tSpan));']);
       
        % equal-weighted returns
        % eval(['p10(' num2str(i) ', :) = mean(Ret(IndStru.idp' num2str(i) ', tSpan));']);
  
end

