
function [Rets,VFs, Divds,Ps,Ks,Is,BMs, Ys,BetaSs,ExpRetSs,simx] = simuSSS(kd0,zd0, N, T, cutoff)

% this function simulates a panel of N firms each with T periods data

load policy.mat

clear j;

Vsim  = zeros(N,T);  Psim = zeros(N,T);   ExpRetsim = zeros(N,T);Isim = zeros(N,T);
Ysim  = zeros(N,T);  Bsim  = zeros(N,T);  Retsim = zeros(N,T);   Bhatsim = zeros(N,T);          
one   = ones(N,T-cutoff-1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% simulate markov process
sysrand  = rand(T, 1);
idiorand = rand(N, T);

xid = zeros(T, 1);
zid = zeros(N, T);
xid(1) = imx;
zid(:, 1) = ones(N, 1)*imz;

cumQx = cumsum(Qx);
cumQz = cumsum(Qz);
 
% Initializing the simulation
ksim    = kd0*ones(1, T);
simx    = ones(T,1)*xbar;
zsim    = zd0*ones(1,T);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Construct 2-D grid using 'meshgrid'
[zs,ks] = meshgrid(z,kgrid);
% simulate time period from 2 to T
for j = 2:T
    
         xid(j) = find(cumQx(:, xid(j-1)) >= sysrand(j), 1); 
         simx(j-1) = x(xid(j));

         for n = 1:N
             zid(n, j)   = find(cumQz(:, zid(n, j-1)) >= idiorand(n, j), 1); 
             zsim(n,j-1) = z(zid(n, j));
         end

        % timing is consistent with the model
        ksim(:,j)     = interp2(zs, ks , squeeze(kprime(:,xid(j),:)),   zsim(:,j-1),ksim(:,j-1),'linear');       % K
        Ysim(:,j-1)   = interp2(zs, ks , squeeze(Y(:,xid(j),:)),        zsim(:,j-1),ksim(:,j-1),'linear');       % Y
        Vsim(:,j-1)   = interp2(zs, ks , squeeze(V(:,xid(j),:)),        zsim(:,j-1),ksim(:,j-1),'linear');       % V
        Psim(:,j-1)   = interp2(zs, ks , squeeze(P(:,xid(j),:)),        zsim(:,j-1),ksim(:,j-1),'linear');       % P
        Bsim(:,j-1)   = interp2(zs, ks , squeeze(Beta(:,xid(j),:)),     zsim(:,j-1),ksim(:,j-1),'linear');       % conditional beta
        ExpRetsim(:,j-1)= interp2(zs,ks , squeeze(ExpRet(:,xid(j),:)),  zsim(:,j-1),ksim(:,j-1),'linear');       % Expected return
        
        ksim(:,j)       = min(kmax,max(kmin,ksim(:,j)));               % boundary control
        Isim(:,j-1)       = ksim(:,j) - (1 - delta)*ksim(:,j-1);       % I
        
end; 

            Divsim   = Vsim - Psim;                                    % Div
            Retsim(:,2:T-1) = Vsim(:,2:T-1)./Psim(:,1:T-2); 
   
       % delete the first period data where no legimate value
            Ret(:,:)        = Retsim(:,cutoff+1:end-1);                 % return is one period ahead of investment
            K(:,:)          = ksim(:,cutoff+1:end-1);
            IT(:,:)         = Isim(:,cutoff:end-2);
            PT(:,:)         = Psim(:,cutoff:end-2);
            Divd            = Divsim(:,cutoff:end-2);
            VF              = Vsim(:,cutoff:end-2);
            BM(:,:)         = K./PT;
            YT(:,:)         = Ysim(:,cutoff:end-2);
            BetaS(:,:)      = Bsim(:,cutoff+1:end-1);
            ExpRetS(:,:)    = ExpRetsim(:,cutoff+1:end-1);
        
       % Remove firms with negative stock price
             P11 = prod(((PT>0)&(VF>0)).*one,2);     DD=repmat(P11,[1,T-cutoff-1]); %set zeros to firms with negative stock price
             P2=PT.*DD;         P3 = reshape(nonzeros(P2), [nnz(P2)/(T-cutoff-1),T-cutoff-1]);  [N2 M] = size(P3);       Ps = P3(1:N2,:);
             V2=VF.*DD;         V3 = reshape(nonzeros(V2), [nnz(V2)/(T-cutoff-1),T-cutoff-1]);       VFs = V3(1:N2,:);
             Divd2=Divd.*DD;    Divd3 = reshape(nonzeros( Divd2), [nnz( Divd2)/(T-cutoff-1),T-cutoff-1]);        Divds =  Divd3(1:N2,:);
             Ret2=Ret.*DD;      Ret3 = reshape(nonzeros(Ret2), [nnz(Ret2)/(T-cutoff-1),T-cutoff-1]);  Rets = Ret3(1:N2,:);
             K2=K.*DD;          K3 = reshape(nonzeros(K2), [nnz(K2)/(T-cutoff-1),T-cutoff-1]);       Ks = K3(1:N2,:);
             I2=IT.*DD;         I3 = reshape(nonzeros(I2), [nnz(I2)/(T-cutoff-1),T-cutoff-1]);       Is = I3(1:N2,:);
             Y2 =YT.*DD;        Y3  = reshape(nonzeros(Y2), [nnz(Y2)/(T-cutoff-1),T-cutoff-1]);    Ys  = Y3(1:N2,:);
             BM2=BM.*DD;        BM3 = reshape(nonzeros(BM2), [nnz(BM2)/(T-cutoff-1),T-cutoff-1]);       BMs = BM3(1:N2,:);
             BetaS2 =BetaS.*DD; BetaS3  = reshape(nonzeros(BetaS2), [nnz(BetaS2)/(T-cutoff-1),T-cutoff-1]);    BetaSs  = BetaS3(1:N2,:);
             ExpRet2 =ExpRetS.*DD;      ExpRet3  = reshape(nonzeros(ExpRet2), [nnz(ExpRet2)/(T-cutoff-1),T-cutoff-1]);    ExpRetSs  = ExpRet3(1:N2,:);
             